@@ -1,10 +1,16 @@
 # Copyright (c) cdr4eelz.
 # Distributed under the terms of the Modified BSD License.
 
+"""\
+Python backend module for SerialHub Widget
+"""
+
 import json
 from pathlib import Path
 
-from .backend import SerialHubWidget, SerialIO
+#Import these so they get re-exported to serialhub package
+from .backend import SerialHubWidget
+from .serialio import SerialIO
 from .nbextension import _jupyter_nbextension_paths
 
 from ._version import __version__
