@@ -4,13 +4,11 @@
 # Copyright (c) cdr4eelz.
 # Distributed under the terms of the Modified BSD License.
 
-"""\
-SerialHub backend widget & support classes
-"""
+"""SerialHub backend widget & support classes"""
 
+from __future__ import absolute_import
 #from __future__ import print_function
-from typing import Sequence, Mapping, Any, ByteString, Optional, NoReturn #, BinaryIO, IO
-import io #, binascii
+from typing import Sequence, Mapping, Any, ByteString, Optional  # , BinaryIO, IO
 
 import ipywidgets #from ipywidgets import DOMWidget, register
 import traitlets
@@ -19,7 +17,8 @@ from ._frontend import module_name, module_version
 
 @ipywidgets.register
 class SerialHubWidget(ipywidgets.DOMWidget):
-    """SerialHubWidget class inherits ipywidgets.DOMWidget
+    """\
+    SerialHubWidget class inherits ipywidgets.DOMWidget
         Model: SerialHubModel, View: SerialHubView
     """
     _model_name = traitlets.Unicode('SerialHubModel').tag(sync=True)
@@ -35,7 +34,8 @@ class SerialHubWidget(ipywidgets.DOMWidget):
         read_only=True,
         help='is_supported is set by frontend to True if the browser supports Web Serial API'
     ).tag(sync=True)
-    status = traitlets.Unicode( #TODO: Consider an Enum or UseEnum approach???
+    #FUTURE: Consider an Enum or UseEnum approach for status traitlet???
+    status = traitlets.Unicode(
         default_value='Checking...',
         help='status of the widget frontend regarding serial port'
     ).tag(sync=True)
@@ -65,35 +65,34 @@ class SerialHubWidget(ipywidgets.DOMWidget):
             'stopBits': 1
         }, help='serial_options to apply when opening serial port'
     ).tag(sync=True)
-    #TODO: Optionally turn off 'sync' attribute for statistics
+    #FUTURE: Optionally turn off 'sync' attribute for statistics (for performance)
     pkt_recv_front = traitlets.Tuple(
         traitlets.Int(), traitlets.Int(),
         default_value=(0, 0),
         read_only=True,
-        help='[pkts,bytes] received by frontend JS reader'
+        help='[bytes,packets] received by frontend JS reader'
     ).tag(sync=True)
     pkt_send_front = traitlets.Tuple(
         traitlets.Int(), traitlets.Int(),
         default_value=(0, 0),
         read_only=True,
-        help='[pkts,bytes] sent to serial port by frontend'
+        help='[bytes,packets] sent to serial port by frontend'
     ).tag(sync=True)
     pkt_recv_back = traitlets.Tuple(
         traitlets.Int(), traitlets.Int(),
         default_value=(0, 0),
-        help='[pkts,bytes] received from trontend by backend callback'
+        help='[bytes,packets] received from trontend by backend callback'
     ).tag(sync=True)
     pkt_send_back = traitlets.Tuple(
         traitlets.Int(), traitlets.Int(),
         default_value=(0, 0),
-        help='[pkts,bytes] sent by backend to frontend'
+        help='[bytes,packets] sent by backend to frontend'
     ).tag(sync=True)
 
-    _cb_recv = None
-
     def __init__(self, *args, **kwargs):
         #TODO: Allow request & serial options to be passed at construction
         ipywidgets.DOMWidget.__init__(self, *args, **kwargs)
+        self._cb_recv = None
         self.on_msg(self.msg_custom)
 
     def on_recv(self, cb_recv):
@@ -160,52 +159,3 @@ class SerialHubWidget(ipywidgets.DOMWidget):
             Optional "errs" for desired encoding error handling (default 'ignore')
         """
         self.write_bytes(data.encode(encoding=enc, errors=errs))
-
-
-#BinaryIO(IO[bytes])
-class SerialIO(io.RawIOBase):
-    """Serial IO proxied to frontend browser serial"""
-
-    widget: SerialHubWidget
-
-    def __init__(self, widget: SerialHubWidget): #, *args, **kwargs):
-        io.RawIOBase.__init__(self)
-        self.widget = widget
-        #TODO: Register callback
-
-    def readable(self) -> bool:
-        return True
-    def writable(self) -> bool:
-        return True
-    def isatty(self) -> bool:
-        return False
-    def seekable(self) -> bool:
-        return False
-
-    def closed(self) -> bool:
-        """Currently True only if widget reports unsupported"""
-        return not self.widget.is_supported
-
-    def write(self, data: bytes) -> Optional[int]:
-        if self.closed():
-            raise ValueError("Stream closed")
-        if len(data) <= 0:
-            return None
-        return 0
-
-    def readinto(self, b: bytearray) -> Optional[int]:
-        if self.closed():
-            raise ValueError("Stream closed")
-        if len(b) <= 0:
-            return None
-        b[0] = 0
-        return 1
-
-    def fileno(self) -> NoReturn:
-        raise OSError("No fileno")
-    def tell(self) -> NoReturn:
-        raise OSError("Not seekable")
-    def seek(self, offset: int, whence = 0) -> NoReturn:
-        raise OSError("Not seekable")
-    def truncate(self, size: Optional[int] = None) -> NoReturn:
-        raise OSError("Not seekable")
